* v0.9.0

  * Numerous small improvements (`#14`_)
  * Support fastparquet (`#21`_)
  * fill_na option (`#22`_)
  * Plotting new threshold plots (`#24`_)
  * Add leaky threshhold to filenames (`#25`_)

* v0.2.0 - S3 compatibility, and minor improvements
* v0.1.0 - Initial Release

.. _#14: https://github.com/mozilla/dye-score/pull/14
.. _#21: https://github.com/mozilla/dye-score/pull/21
.. _#22: https://github.com/mozilla/dye-score/pull/22
.. _#24: https://github.com/mozilla/dye-score/pull/24
.. _#25: https://github.com/mozilla/dye-score/pull/25
